@@ -1,3 +1,3 @@
 from genz_tokenize.tokenize import Tokenize
 from genz_tokenize.tokenize import TokenizeForBert
-# from genz_tokenize.tokenize import get_embedding_matrix
+from genz_tokenize.tokenize import get_embedding_matrix
